@@ -135,8 +135,9 @@ class ConfigUIMaemo5(AbstractConfigUI):
       pass
     else:
       ts = control.get_selector()
-      model = ts.get_model(0)
-      citer = model.get_iter_first()
-      ts.get_selected(0, citer)
+      #model = ts.get_model(0)
+      #citer = model.get_iter_first()
+      #ts.get_selected(0, citer)
+      model, citer = ts.get_selected(0)
       value = vtype(model.get_value(citer, 1))
     return value
