@@ -68,6 +68,9 @@ class Config():
     except KeyError:
       self.add_entry(self, key_name, key_value, save, callback)
 
+  def set_option(self, key, value):
+    self.__options[key] = value
+
   def set_options(self, options):
     self.__options = options
 
